@@ -3,6 +3,7 @@
 # Copyright (C) 2007, 2008 Tom Cato Amundsen
 # License is GPL, see file COPYING
 
+from __future__ import absolute_import
 import unittest
 import sys
 import os
@@ -20,54 +21,54 @@ def f(s):
 
 sys.displayhook = f
 
-from src import testlib
-import src.i18n
-src.i18n.setup(".")
+from solfege import testlib
+import solfege.i18n
+solfege.i18n.setup(".")
 
-import src.lessonfile
-src.lessonfile.manager = src.lessonfile.LessonFileManager(False)
-import src.statistics
-src.statistics.db = src.statistics.DB(None)
+from solfege import lessonfile
+lessonfile.manager = lessonfile.LessonFileManager()
+lessonfile.infocache = lessonfile.InfoCache()
+import solfege.statistics
+solfege.db = solfege.statistics.DB(None)
 
 import tempfile
-import src.lessonfile
-src.lessonfile.MusicBaseClass.temp_dir = tempfile.mkdtemp(prefix="solfege-")
+lessonfile.MusicBaseClass.temp_dir = tempfile.mkdtemp(prefix="solfege-")
 
-import src.cfg
-src.cfg.initialise("default.config", None, "")
-src.cfg.set_int('config/preferred_instrument', 0)
-src.cfg.set_int('config/lowest_instrument', 1)
-src.cfg.set_int('config/middle_instrument', 2)
-src.cfg.set_int('config/highest_instrument', 3)
-src.cfg.set_int('config/lowest_instrument_volume', 121)
-src.cfg.set_int('config/middle_instrument_volume', 122)
-src.cfg.set_int('config/highest_instrument_volume', 123)
-src.cfg.set_bool('config/override_default_instrument', False)
-src.cfg.set_bool('testing/may_play_sound', False)
+from solfege import cfg
+cfg.initialise("default.config", None, "")
+cfg.set_int('config/preferred_instrument', 0)
+cfg.set_int('config/lowest_instrument', 1)
+cfg.set_int('config/middle_instrument', 2)
+cfg.set_int('config/highest_instrument', 3)
+cfg.set_int('config/lowest_instrument_volume', 121)
+cfg.set_int('config/middle_instrument_volume', 122)
+cfg.set_int('config/highest_instrument_volume', 123)
+cfg.set_bool('config/override_default_instrument', False)
+cfg.set_bool('testing/may_play_sound', False)
 
 if os.path.exists(testlib.outdir):
     shutil.rmtree(testlib.outdir)
 os.mkdir(testlib.outdir)
 
-import soundcard
-from src.osutils import *
+from solfege import soundcard
+from solfege.osutils import *
 soundcard.initialise_external_midiplayer(
-    src.cfg.get_string("sound/midi_player"))
+    cfg.get_string("sound/midi_player"))
 
 soundcard.synth.start_testmode()
 
 
-import mpd.tests
-import soundcard.tests
-import src.tests
-import src.tests.test_cfg
+import solfege.mpd.tests
+import solfege.soundcard.tests
+import solfege.tests
+import solfege.tests.test_cfg
 
 # test_cfg has to be called last because it changes the cfg database.
 suite = unittest.TestSuite((
-    mpd.tests.suite,
-    soundcard.tests.suite,
-    src.tests.suite,
-    src.tests.test_cfg.suite,
+    solfege.mpd.tests.suite,
+    solfege.soundcard.tests.suite,
+    solfege.tests.suite,
+    solfege.tests.test_cfg.suite,
 ))
 
 class MyProg(unittest.TestProgram):
